This set of IPython magic extensions is provided to the first year students enrolled in the algorithmics course at ISFATES (University of Lorraine).

Installation
------------

The recommended way to install the algo_magic extension is to use pip:

::

    pip install algo_magic

If this fails, ensure first you have a working Python 3 installation.


Usage
-----

Load the magic extensions:

::

    %load_ext algo_magic


More info
---------

`Source code on GitHub
<https://github.com/laowantong/algo_magic/>`_
